@@ -20,7 +20,7 @@
  */
 
 #include <tqiodevice.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <stdlib.h>
 #include "qxcfi.h"
 
@@ -28,7 +28,7 @@
 // Change a TQRgb value's alpha only. (an optimization)
 inline TQRgb tqRgba ( TQRgb rgb, int a )
 {
-  return ( ( a & 0xff ) << 24 | ( rgb & TQRGB_MASK ) );
+  return ( ( a & 0xff ) << 24 | ( rgb & TQT_RGB_MASK ) );
 }
 
 
@@ -427,14 +427,14 @@ void XCFImageFormat::readXCF ( TQImageIO* image_io )
   xcf_io.readRawBytes( tag, sizeof(tag) );
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on header tag" );
+    tqDebug( "XCF: read failure on header tag" );
     return;
   }
 
   xcf_io >> xcf_image.width >> xcf_image.height >> xcf_image.type;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on image info" );
+    tqDebug( "XCF: read failure on image info" );
     return;
   }
 
@@ -454,7 +454,7 @@ void XCFImageFormat::readXCF ( TQImageIO* image_io )
     xcf_io >> layer_offset;
 
     if ( xcf_io.failed() ) {
-      qDebug( "XCF: read failure on layer offsets" );
+      tqDebug( "XCF: read failure on layer offsets" );
       return;
     }
 
@@ -466,7 +466,7 @@ void XCFImageFormat::readXCF ( TQImageIO* image_io )
   xcf_image.num_layers = layer_offsets.size();
 
   if ( layer_offsets.size() == 0 ) {
-    qDebug( "XCF: no layers!" );
+    tqDebug( "XCF: no layers!" );
     return;
   }
 
@@ -481,7 +481,7 @@ void XCFImageFormat::readXCF ( TQImageIO* image_io )
   }
 
   if ( !xcf_image.initialized ) {
-    qDebug( "XCF: no visible layers!" );
+    tqDebug( "XCF: no visible layers!" );
     return;
   }
 
@@ -530,7 +530,7 @@ void XCFImageFormat::initializeImage ( XCFImage& xcf_image )
       image.fill( tqRgb( 255, 255, 255 ) );
       break;
     } // else, fall through to 32-bit representation
-
+      // fall through
   case RGBA_GIMAGE:
     image.create( xcf_image.width, xcf_image.height, 32 );
     image.fill( tqRgba( 255, 255, 255, 0 ) );
@@ -546,7 +546,7 @@ void XCFImageFormat::initializeImage ( XCFImage& xcf_image )
       image.fill( 255 );
       break;
     } // else, fall through to 32-bit representation
-
+      // fall through
   case GRAYA_GIMAGE:
     image.create( xcf_image.width, xcf_image.height, 32 );
     image.fill( tqRgba( 255, 255, 255, 0 ) );
@@ -763,7 +763,7 @@ bool XCFImageFormat::loadImageProperties ( SafeDataStream& xcf_io,
     TQByteArray bytes;
 
     if ( !loadProperty( xcf_io, type, bytes ) ) {
-      qDebug( "XCF: error loading global image properties" );
+      tqDebug( "XCF: error loading global image properties" );
       return false;
     }
 
@@ -833,7 +833,7 @@ bool XCFImageFormat::loadImageProperties ( SafeDataStream& xcf_io,
       break;
 
     default:
-      qDebug( "XCF: unimplemented image property %d, size %d", type, bytes.size() );
+      tqDebug( "XCF: unimplemented image property %d, size %d", type, bytes.size() );
     }
   }
 }
@@ -855,7 +855,7 @@ bool XCFImageFormat::loadLayer ( SafeDataStream& xcf_io, XCFImage& xcf_image )
   xcf_io >> layer.width >> layer.height >> layer.type >> layer.name;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on layer" );
+    tqDebug( "XCF: read failure on layer" );
     return false;
   }
 
@@ -877,7 +877,7 @@ bool XCFImageFormat::loadLayer ( SafeDataStream& xcf_io, XCFImage& xcf_image )
   xcf_io >> layer.hierarchy_offset >> layer.mask_offset;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on layer image offsets" );
+    tqDebug( "XCF: read failure on layer image offsets" );
     return false;
   }
 
@@ -933,7 +933,7 @@ bool XCFImageFormat::loadLayerProperties ( SafeDataStream& xcf_io, Layer& layer
     TQByteArray bytes;
 
     if ( !loadProperty( xcf_io, type, bytes ) ) {
-      qDebug( "XCF: error loading layer properties" );
+      tqDebug( "XCF: error loading layer properties" );
       return false;
     }
 
@@ -988,7 +988,7 @@ bool XCFImageFormat::loadLayerProperties ( SafeDataStream& xcf_io, Layer& layer
       break;
 
     default:
-      qDebug( "XCF: unimplemented layer property %d, size %d", type, bytes.size() );
+      tqDebug( "XCF: unimplemented layer property %d, size %d", type, bytes.size() );
     }
   }
 }
@@ -1007,7 +1007,7 @@ bool XCFImageFormat::loadChannelProperties ( SafeDataStream& xcf_io, Layer& laye
     TQByteArray bytes;
 
     if ( !loadProperty( xcf_io, type, bytes ) ) {
-      qDebug( "XCF: error loading channel properties" );
+      tqDebug( "XCF: error loading channel properties" );
       return false;
     }
 
@@ -1039,7 +1039,7 @@ bool XCFImageFormat::loadChannelProperties ( SafeDataStream& xcf_io, Layer& laye
       break;
 
     default:
-      qDebug( "XCF: unimplemented channel property %d, size %d", type, bytes.size() );
+      tqDebug( "XCF: unimplemented channel property %d, size %d", type, bytes.size() );
     }
   }
 }
@@ -1062,7 +1062,7 @@ bool XCFImageFormat::loadHierarchy ( SafeDataStream& xcf_io, Layer& layer )
   xcf_io >> width >> height >> bpp >> offset;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on layer %s image header", layer.name );
+    tqDebug( "XCF: read failure on layer %s image header", layer.name );
     return false;
   }
 
@@ -1075,7 +1075,7 @@ bool XCFImageFormat::loadHierarchy ( SafeDataStream& xcf_io, Layer& layer )
     xcf_io >> junk;
 
     if ( xcf_io.failed() ) {
-      qDebug( "XCF: read failure on layer %s level offsets", layer.name );
+      tqDebug( "XCF: read failure on layer %s level offsets", layer.name );
       return false;
     }
   } while ( junk != 0 );
@@ -1108,7 +1108,7 @@ bool XCFImageFormat::loadLevel ( SafeDataStream& xcf_io, Layer& layer, TQ_INT32
   xcf_io >> width >> height >> offset;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on layer %s level info", layer.name );
+    tqDebug( "XCF: read failure on layer %s level info", layer.name );
     return false;
   }
 
@@ -1118,7 +1118,7 @@ bool XCFImageFormat::loadLevel ( SafeDataStream& xcf_io, Layer& layer, TQ_INT32
     for ( uint i = 0; i < layer.ncols; i++ ) {
 
       if ( offset == 0 ) {
-	qDebug( "XCF: incorrect number of tiles in layer %s", layer.name );
+	tqDebug( "XCF: incorrect number of tiles in layer %s", layer.name );
 	return false;
       }
 
@@ -1129,7 +1129,7 @@ bool XCFImageFormat::loadLevel ( SafeDataStream& xcf_io, Layer& layer, TQ_INT32
       xcf_io >> offset2;
 
       if ( xcf_io.failed() ) {
-	qDebug( "XCF: read failure on layer %s level offset look-ahead",
+	tqDebug( "XCF: read failure on layer %s level offset look-ahead",
 		layer.name );
 	return false;
       }
@@ -1157,7 +1157,7 @@ bool XCFImageFormat::loadLevel ( SafeDataStream& xcf_io, Layer& layer, TQ_INT32
       xcf_io >> offset;
 
       if ( xcf_io.failed() ) {
-	qDebug( "XCF: read failure on layer %s level offset", layer.name );
+	tqDebug( "XCF: read failure on layer %s level offset", layer.name );
 	return false;
       }
     }
@@ -1181,7 +1181,7 @@ bool XCFImageFormat::loadMask ( SafeDataStream& xcf_io, Layer& layer )
   xcf_io >> width >> height >> name;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on mask info" );
+    tqDebug( "XCF: read failure on mask info" );
     return false;
   }
 
@@ -1194,7 +1194,7 @@ bool XCFImageFormat::loadMask ( SafeDataStream& xcf_io, Layer& layer )
   xcf_io >> hierarchy_offset;
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on mask image offset" );
+    tqDebug( "XCF: read failure on mask image offset" );
     return false;
   }
 
@@ -1245,7 +1245,7 @@ bool XCFImageFormat::loadTileRLE ( SafeDataStream& xcf_io, uchar* tile, int imag
 
   if ( read_length<=0 ) {
     delete[] xcfodata;
-    qDebug( "XCF: read failure on tile" );
+    tqDebug( "XCF: read failure on tile" );
     return false;
   }
 
@@ -1326,7 +1326,7 @@ bool XCFImageFormat::loadTileRLE ( SafeDataStream& xcf_io, uchar* tile, int imag
 
  bogus_rle:
 
-  qDebug( "The run length encoding could not be decoded properly" );
+  tqDebug( "The run length encoding could not be decoded properly" );
   delete[] xcfodata;
   return false;
 }
@@ -1425,7 +1425,7 @@ bool XCFImageFormat::loadProperty ( SafeDataStream& xcf_io, PropType& type,
   type=static_cast<PropType>(tmp);
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on property type" );
+    tqDebug( "XCF: read failure on property type" );
     return false;
   }
 
@@ -1445,13 +1445,13 @@ bool XCFImageFormat::loadProperty ( SafeDataStream& xcf_io, PropType& type,
     TQ_UINT32 ignoredSize, ncolors;
     xcf_io >> ignoredSize;
     if ( xcf_io.failed() ) {
-      qDebug( "XCF: read failure on property %d size", type );
+      tqDebug( "XCF: read failure on property %d size", type );
       return false;
     }
 
     xcf_io >> ncolors;
     if ( xcf_io.failed() ) {
-      qDebug( "XCF: read failure on property %d size", type );
+      tqDebug( "XCF: read failure on property %d size", type );
       return false;
     }
     xcf_io.device()->ungetch( ncolors & 0xff);
@@ -1475,7 +1475,7 @@ bool XCFImageFormat::loadProperty ( SafeDataStream& xcf_io, PropType& type,
     xcf_io >> size >> factor >> digits;
 
     if ( xcf_io.failed() ) {
-      qDebug( "XCF: read failure on property %d", type );
+      tqDebug( "XCF: read failure on property %d", type );
       return false;
     }
 
@@ -1483,7 +1483,7 @@ bool XCFImageFormat::loadProperty ( SafeDataStream& xcf_io, PropType& type,
       xcf_io >> unit_strings;
 
       if ( xcf_io.failed() ) {
-	qDebug( "XCF: read failure on property %d", type );
+	tqDebug( "XCF: read failure on property %d", type );
 	return false;
       }
 
@@ -1497,7 +1497,7 @@ bool XCFImageFormat::loadProperty ( SafeDataStream& xcf_io, PropType& type,
     xcf_io.readBytes( data, size );
 
   if ( xcf_io.failed() ) {
-    qDebug( "XCF: read failure on property %d data, size %d", type, size );
+    tqDebug( "XCF: read failure on property %d data, size %d", type, size );
     return false;
   }
 
