@@ -1,4 +1,3 @@
-// vi: tabstop=4 shiftwidth=4 noexpandtab
 /*
 Gwenview - A simple image viewer for TDE
 Copyright 2005 Aurelien Gateau
@@ -53,10 +52,10 @@ ThumbnailDetailsDialog::ThumbnailDetailsDialog(FileThumbnailView* view)
 	d->mContent->mShowFileSize->setChecked(details & FileThumbnailView::FILESIZE);
 	d->mContent->mShowImageSize->setChecked(details & FileThumbnailView::IMAGESIZE);
 
-	connect(d->mContent->mShowFileName, TQT_SIGNAL(toggled(bool)), TQT_SLOT(applyChanges()) );
-	connect(d->mContent->mShowFileDate, TQT_SIGNAL(toggled(bool)), TQT_SLOT(applyChanges()) );
-	connect(d->mContent->mShowFileSize, TQT_SIGNAL(toggled(bool)), TQT_SLOT(applyChanges()) );
-	connect(d->mContent->mShowImageSize, TQT_SIGNAL(toggled(bool)), TQT_SLOT(applyChanges()) );
+	connect(d->mContent->mShowFileName, TQ_SIGNAL(toggled(bool)), TQ_SLOT(applyChanges()) );
+	connect(d->mContent->mShowFileDate, TQ_SIGNAL(toggled(bool)), TQ_SLOT(applyChanges()) );
+	connect(d->mContent->mShowFileSize, TQ_SIGNAL(toggled(bool)), TQ_SLOT(applyChanges()) );
+	connect(d->mContent->mShowImageSize, TQ_SIGNAL(toggled(bool)), TQ_SLOT(applyChanges()) );
 }
 
 ThumbnailDetailsDialog::~ThumbnailDetailsDialog() {
