@@ -89,35 +89,35 @@ GVImagePart::GVImagePart(TQWidget* parentWidget, const char* /*widgetName*/, TQO
 
 	// Create the widgets
 	mDocument = new Document(this);
-	connect( mDocument, TQT_SIGNAL( loading()), TQT_SLOT( slotLoading()));
-	connect( mDocument, TQT_SIGNAL( loaded(const KURL&)), TQT_SLOT( slotLoaded(const KURL&)));
+	connect( mDocument, TQ_SIGNAL( loading()), TQ_SLOT( slotLoading()));
+	connect( mDocument, TQ_SIGNAL( loaded(const KURL&)), TQ_SLOT( slotLoaded(const KURL&)));
 	mImageView = new ImageView(parentWidget, mDocument, actionCollection());
-	connect( mImageView, TQT_SIGNAL(requestContextMenu(const TQPoint&)),
-		this, TQT_SLOT(openContextMenu(const TQPoint&)) );
+	connect( mImageView, TQ_SIGNAL(requestContextMenu(const TQPoint&)),
+		this, TQ_SLOT(openContextMenu(const TQPoint&)) );
 	setWidget(mImageView);
 
 	mDirLister = new KDirLister;
 	mDirLister->setAutoErrorHandlingEnabled( false, 0 );
 	mDirLister->setMainWindow(TDEApplication::kApplication()->mainWidget());
-	connect( mDirLister, TQT_SIGNAL( clear()), TQT_SLOT( dirListerClear()));
-	connect( mDirLister, TQT_SIGNAL( newItems( const KFileItemList& )),
-		TQT_SLOT( dirListerNewItems( const KFileItemList& )));
-	connect(mDirLister,TQT_SIGNAL(deleteItem(KFileItem*)),
-		TQT_SLOT(dirListerDeleteItem(KFileItem*)) );
+	connect( mDirLister, TQ_SIGNAL( clear()), TQ_SLOT( dirListerClear()));
+	connect( mDirLister, TQ_SIGNAL( newItems( const KFileItemList& )),
+		TQ_SLOT( dirListerNewItems( const KFileItemList& )));
+	connect(mDirLister,TQ_SIGNAL(deleteItem(KFileItem*)),
+		TQ_SLOT(dirListerDeleteItem(KFileItem*)) );
 	
 	TQStringList mimeTypes=MimeTypeUtils::rasterImageMimeTypes();
 	mDirLister->setMimeFilter(mimeTypes);
 	mPreviousImage=new TDEAction(i18n("&Previous Image"),
 		TQApplication::reverseLayout() ? "1rightarrow":"1leftarrow", Key_BackSpace,
-		this,TQT_SLOT(slotSelectPrevious()), actionCollection(), "previous");
+		this,TQ_SLOT(slotSelectPrevious()), actionCollection(), "previous");
 	mNextImage=new TDEAction(i18n("&Next Image"),
 		TQApplication::reverseLayout() ? "1leftarrow":"1rightarrow", Key_Space,
-		this,TQT_SLOT(slotSelectNext()), actionCollection(), "next");
+		this,TQ_SLOT(slotSelectNext()), actionCollection(), "next");
 	updateNextPrevious();
 
-	KStdAction::saveAs( this, TQT_SLOT(saveAs()), actionCollection(), "saveAs" );
-	new TDEAction(i18n("Rotate &Left"), "object-rotate-left", CTRL + Key_L, this, TQT_SLOT(rotateLeft()), actionCollection(), "rotate_left");
-	new TDEAction(i18n("Rotate &Right"), "object-rotate-right", CTRL + Key_R, this, TQT_SLOT(rotateRight()), actionCollection(), "rotate_right");
+	KStdAction::saveAs( this, TQ_SLOT(saveAs()), actionCollection(), "saveAs" );
+	new TDEAction(i18n("Rotate &Left"), "object-rotate-left", CTRL + Key_L, this, TQ_SLOT(rotateLeft()), actionCollection(), "rotate_left");
+	new TDEAction(i18n("Rotate &Right"), "object-rotate-right", CTRL + Key_R, this, TQ_SLOT(rotateRight()), actionCollection(), "rotate_right");
 
 	setXMLFile( "gvimagepart/gvimagepart.rc" );
 }
@@ -201,7 +201,7 @@ void GVImagePart::slotLoaded(const KURL& url) {
 	prefetchDone();
 	mPrefetch = ImageLoader::loader( mLastDirection == DirectionPrevious ? previousURL() : nextURL(),
 		this, BUSY_PRELOADING );
-	connect( mPrefetch, TQT_SIGNAL( imageLoaded( bool )), TQT_SLOT( prefetchDone()));
+	connect( mPrefetch, TQ_SIGNAL( imageLoaded( bool )), TQ_SLOT( prefetchDone()));
 }
 
 void GVImagePart::prefetchDone() {
@@ -351,8 +351,8 @@ void GVImagePart::saveOriginalAs() {
 		// We need to read the image again. Let TDEIO::copy do the work.
 		TDEIO::Job* job = TDEIO::copy(srcURL, dstURL);
 		job->setWindow(widget());
-		connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
-			this, TQT_SLOT(showJobError(TDEIO::Job*)) );
+		connect(job, TQ_SIGNAL(result(TDEIO::Job*)),
+			this, TQ_SLOT(showJobError(TDEIO::Job*)) );
 		return;
 	}
 
@@ -388,8 +388,8 @@ DataUploader::DataUploader(TQWidget* dialogParent, const TQByteArray& data, cons
 	tmpURL.setPath(mTempFile.name());
 	TDEIO::Job* job = TDEIO::copy(tmpURL, dstURL);
 	job->setWindow(dialogParent);
-	connect(job, TQT_SIGNAL(result(TDEIO::Job*)),
-		this, TQT_SLOT(slotJobFinished(TDEIO::Job*)) );
+	connect(job, TQ_SIGNAL(result(TDEIO::Job*)),
+		this, TQ_SLOT(slotJobFinished(TDEIO::Job*)) );
 }
 
 
@@ -418,7 +418,7 @@ void GVImagePart::openContextMenu(const TQPoint& pos) {
 	TQString doc = KXMLGUIFactory::readConfigFile( "gvimagepartpopup.rc", true, instance() );
 	PopupGUIClient guiClient(instance(), doc);
 	
-	KStdAction::saveAs( this, TQT_SLOT(saveAs()), guiClient.actionCollection(), "saveAs" );
+	KStdAction::saveAs( this, TQ_SLOT(saveAs()), guiClient.actionCollection(), "saveAs" );
 	
 	KParts::URLArgs urlArgs;
 	urlArgs.serviceType = mDocument->mimeType();
