@@ -2329,6 +2329,7 @@ jtransform_adjust_parameters (j_decompress_ptr srcinfo,
 			      jvirt_barray_ptr *src_coef_arrays,
 			      jpeg_transform_info *info)
 {
+  (void) srcinfo; /* unused */
   /* If force-to-grayscale is requested, adjust destination parameters */
   if (info->force_grayscale) {
     /* We use jpeg_set_colorspace to make sure subsidiary settings get fixed
@@ -2455,6 +2456,8 @@ jtransform_execute_transformation (j_decompress_ptr srcinfo,
 GLOBAL(void)
 jcopy_markers_setup (j_decompress_ptr srcinfo, JCOPY_OPTION option)
 {
+  (void) srcinfo; /* maybe unused */
+  (void) option;  /* maybe unused */
 #ifdef SAVE_MARKERS_SUPPORTED
   int m;
 
@@ -2481,6 +2484,7 @@ GLOBAL(void)
 jcopy_markers_execute (j_decompress_ptr srcinfo, j_compress_ptr dstinfo,
 		       JCOPY_OPTION option)
 {
+  (void) option; /* unused */
   jpeg_saved_marker_ptr marker;
 
   /* In the current implementation, we don't actually need to examine the
@@ -2522,4 +2526,4 @@ jcopy_markers_execute (j_decompress_ptr srcinfo, j_compress_ptr dstinfo,
   }
 }
 
-#endif // JPEG_LIB_VERSION >= 80
\ No newline at end of file
+#endif // JPEG_LIB_VERSION >= 80
